# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './kuafu/resources/ui_library.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_librarywidget(object):
    def setupUi(self, librarywidget):
        librarywidget.setObjectName("librarywidget")
        librarywidget.resize(1101, 701)
        self.horizontalLayout = QtWidgets.QHBoxLayout(librarywidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.splitter_main = QtWidgets.QSplitter(librarywidget)
        self.splitter_main.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_main.setObjectName("splitter_main")
        self.fileview = QtWidgets.QTreeView(self.splitter_main)
        self.fileview.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.fileview.setObjectName("fileview")
        self.splitter_doc = QtWidgets.QSplitter(self.splitter_main)
        self.splitter_doc.setOrientation(QtCore.Qt.Vertical)
        self.splitter_doc.setObjectName("splitter_doc")
        self.layoutWidget = QtWidgets.QWidget(self.splitter_doc)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tocPushButton1 = TocPushButton(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tocPushButton1.sizePolicy().hasHeightForWidth())
        self.tocPushButton1.setSizePolicy(sizePolicy)
        self.tocPushButton1.setObjectName("tocPushButton1")
        self.verticalLayout.addWidget(self.tocPushButton1)
        self.preview_graphicsview = DocGraphicsView(self.layoutWidget)
        self.preview_graphicsview.setObjectName("preview_graphicsview")
        self.verticalLayout.addWidget(self.preview_graphicsview)
        self.preview_graphicsview_2 = DocGraphicsView(self.splitter_doc)
        self.preview_graphicsview_2.setObjectName("preview_graphicsview_2")
        self.thumb_graphicsview = ThumbGraphicsView(self.splitter_main)
        self.thumb_graphicsview.setMinimumSize(QtCore.QSize(150, 0))
        self.thumb_graphicsview.setMaximumSize(QtCore.QSize(600, 16777215))
        self.thumb_graphicsview.setObjectName("thumb_graphicsview")
        self.horizontalLayout.addWidget(self.splitter_main)

        self.retranslateUi(librarywidget)
        QtCore.QMetaObject.connectSlotsByName(librarywidget)

    def retranslateUi(self, librarywidget):
        _translate = QtCore.QCoreApplication.translate
        librarywidget.setWindowTitle(_translate("librarywidget", "Form"))
        self.tocPushButton1.setText(_translate("librarywidget", " ᐅ "))
from docgraphicsview import DocGraphicsView
from thumbgraphicsview import ThumbGraphicsView
from tocpushbutton import TocPushButton
